/*
 *  eShutterSDK.h
 *  eShutterSDK
 *
 *  Created by Martin Widmann on 07.02.12.
 *  Copyright 2012 Sinar Photography AG. All rights reserved.
 *
 */

#include "eShutterSDKDatatypes.h"

#ifndef eShutterSDKH
#define eShutterSDKH

#ifdef __cplusplus 
	extern "C" { 
#endif

/**
 Init the framework
 
 The shutter will be connected automatically as soon as it is attached
 Only one shutter can be supoorted at a time
 */
unsigned int ESDKInit();
		
/**
 Clean up the internals of the framework
 */
unsigned int ESDKExit();

/**
 Return the connected state of the shutter
 TRUE  := Connected
 FALSE := Not connected
 */
unsigned int ESDKGetConnected(Bool* outConnected);

/**
 Number of available aperture positions for the currently attached lens
 From one step to the other is a 1/6 exposure value difference
 */
unsigned int ESDKGetNumberOfApertureSteps(unsigned int* outNumber);
		
/**
 Get the index of the internal aperture table for the lens starting aperture
 Index 0 is f1.0. The aperture steps are in 1/6 exposure values
 f5.6 is at index 30
 */
unsigned int ESDKGetMinApertureIndex(unsigned int* outIndex);		

/**
 Same as ESDKGetMinApertureIndex. Gets the index of the maximum (smallest)
 aperture
 */
unsigned int ESDKGetMaxApertureIndex(unsigned int* outIndex);
		
/**
 Gets the double value of the aperture at the specified index
 */
unsigned int ESDKGetApertureValue(unsigned int inIndex, double* outValue);

/**
 Gets the display string for the aperture at the specified index
 */
unsigned int ESDKGetApertureString(unsigned int inIndex, char* outBuffer, unsigned int inBufferSize);

/**
 Gets the index of the current aperture
 */
unsigned int ESDKGetAperture(unsigned int* outIndex);

/**
 Set a new aperture position via the index
 */
unsigned int ESDKSetAperture(unsigned int inIndex);

/**
 Number of available exposure time steps
 From one step to the other is a 1/6 exposure value difference
 */
unsigned int ESDKGetNumberOfExposureTimeSteps(unsigned int* outNumber);
		
/**
 Get the index of the internal exposure time table for the shutter minimum
 Exposure time. 1/125 seconds is at index 36 for example
 */
unsigned int ESDKGetMinExposureTimeIndex(unsigned int* outIndex);		

/**
 Get the index of the maximum exposure time supported
 */
unsigned int ESDKGetMaxExposureTimeIndex(unsigned int* outIndex);
		
/**
 Get the double value of the exact exposure time for the specified index.
 */
unsigned int ESDKGetExposureTimeValue(unsigned int inIndex, double* outValue);

/**
 Get the display string of the exposure time for the specified index.
 The string is not in mathematically exact but represents the photographically
 common values
 */
unsigned int ESDKGetExposureTimeString(unsigned int inIndex, char* outBuffer, unsigned int inBufferSize);

/**
 Get the current exposure time as index
 */
unsigned int ESDKGetExposureTime(unsigned int* outIndex);
		
/**
 Set the exposuretime by index
 */
unsigned int ESDKSetExposureTime(unsigned int inIndex);

/**
 Get the current flash mode
 */
unsigned int ESDKGetFlashMode(unsigned int* outFlashMode);
		
/**
 Set the flash mode
 */
unsigned int ESDKSetFlashMode(unsigned int inMode);

/**
 Release the shutter. The function returns as soon as
 the electronics is ready for another release.
 This can result in a burst of 3 consecutive exposures. Then
 the electronics needs som more time. For longer exposure times, 
 the function may return before the exposure is complete.
 To check, if the shutter is ready and not currently busy with an exposure
 see ESDKGetIsReleaseActive
 */
unsigned int ESDKRelease();
		
/**
 If the exposure time is long, the exposure can be interrupted
 with this function.
 */
unsigned int ESDKAbortExposure();
		
/**
 Returns, if there is currently an exposure going on
 0 := no release alias expsoure active
 1 := the shutter is currently in exposure/release mode
 */
unsigned int ESDKGetIsReleaseActive(Bool* outActive);

/**
 Returns the stop down state of the aperture
 See ESDKStopDown for possible values
 */
unsigned int ESDKGetStopDown(Bool* outStopDown);
	
/**
 Set tje aperture stop down state
 */
unsigned int ESDKSetStopDown(Bool inStopDown);

/**
 Returns the shutter open state. See enum ESDKShutterOpen
 */
unsigned int ESDKGetShutterOpen(Bool* outShutterOpen);

/**
 Set the shutter open state
 */
unsigned int ESDKSetShutterOpen(Bool inShutterOpen);

/**
 Get the lens manufacturer name. The string length maximum is 40 characters.
 Example "Sinar Photography AG"
 */
unsigned int ESDKGetManufacturer(char* outBuffer, unsigned int inBufferSize);

/**
 Get the lens type name. The string length maximum is 40 characters. The focal length 
 or open aperture are note included
 Example: "Sinaron Digital HR"
 */
unsigned int ESDKGetLensType(char* outBuffer, unsigned int inBufferSize);

/**
 Get the manufacturers article number for the current lens.
 The string length maximum is 20 characters.
 Example: "443.86.107" for Sinaron Digital HR 5.6/70
 */
unsigned int ESDKGetLensArticleNumber(char* outBuffer, unsigned int inBufferSize);
		
/**
 Get the serial number for the current lens. The string length maximum is 10 characters.
 */
unsigned int ESDKGetLensSerialNumber(char* outBuffer, unsigned int inBufferSize);
		
/**
 Get the focal length of the current lens as integer value.
 */
unsigned int ESDKGetFocalLength(unsigned int* outFocalLength);

/**
 Get the wake up delay that is currently set. 
 The wake up delay is prepended to the exposure before the shutter opens.
 */
unsigned int ESDKGetWakeUpDelay(unsigned int* outDelay);
		
/**
 Set the wake up delay. The delay unit is milliseconds
 */
unsigned int ESDKSetWakeUpDelay(unsigned int inDelay);

/**
 For backs, that need a separate signal preceding the actual capture signal
 this can be set with the WakeUpWithSeparateSignal functions
 
 This function returns the current state of the setting.
 See ESDKSeparateWakeUpSignal
 */
unsigned int ESDKGetWakeUpWithSeparateSignal(Bool* outSeparate);
		
/**
 Switch on/off the sepearate signal that preceeds the exposure signal.
 See ESDKSeparateWakeUpSignal
 */
unsigned int ESDKSetWakeUpWithSeparateSignal(Bool inSeparate);

/**
 Returns the firmware version as integer number
 Example 1004 stand for 1.004
 */
unsigned int ESDKGetFirmwareVersion(unsigned int* outFirmware);
		
/**
 Get the number of shutter actuations
 */
unsigned int ESDKGetShutterCount(unsigned long int* outCount);
		
/**
 Get the number of aperture movements
 */
unsigned int ESDKGetApertureCount(unsigned long int* outCount);


#ifdef __cplusplus
	}
#endif

#endif